@@ -518,7 +518,10 @@ class DescribeMachineUnderwriteResponse(AbstractModel):
         :type MainTaskId: str
         :param UnderwriteTaskId: 核保任务ID
         :type UnderwriteTaskId: str
-        :param Status: 状态码
+        :param Status: 结果状态：
+0：返回成功
+1：结果未生成
+2：结果生成失败
         :type Status: int
         :param UnderwriteResults: 机器核保结果
         :type UnderwriteResults: list of MachineUnderwriteOutput
@@ -558,7 +561,9 @@ class DescribeReportClassifyRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ServiceType: 服务类型（Structured/Underwrite）
+        :param ServiceType: 服务类型
+Structured 仅结构化
+Underwrite 结构化+核保
         :type ServiceType: str
         :param FileList: 文件地址数组
         :type FileList: list of str
@@ -937,7 +942,10 @@ class DescribeUnderwriteTaskResponse(AbstractModel):
         :type MainTaskId: str
         :param UnderwriteTaskId: 核保任务ID
         :type UnderwriteTaskId: str
-        :param Status: 状态码
+        :param Status: 结果状态：
+0：返回成功
+1：结果未生成
+2：结果生成失败
         :type Status: int
         :param UnderwriteResults: 核保结果
         :type UnderwriteResults: list of UnderwriteOutput
@@ -1304,11 +1312,14 @@ class StructureResultObject(AbstractModel):
         :type StructureResult: str
         :param SubTaskId: 子任务ID
         :type SubTaskId: str
+        :param TaskFiles: 任务文件列表
+        :type TaskFiles: list of str
         """
         self.Code = None
         self.TaskType = None
         self.StructureResult = None
         self.SubTaskId = None
+        self.TaskFiles = None
 
 
     def _deserialize(self, params):
@@ -1316,6 +1327,7 @@ class StructureResultObject(AbstractModel):
         self.TaskType = params.get("TaskType")
         self.StructureResult = params.get("StructureResult")
         self.SubTaskId = params.get("SubTaskId")
+        self.TaskFiles = params.get("TaskFiles")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1446,9 +1458,9 @@ class UploadMedicalFileRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param File: 文件内容的base64的值。FileBase64与FileURL有一个不为空即可，若FileURL同时存在，那么取FileBase64。
+        :param File: 文件的字节内容。File与FileURL有一个不为空即可，若FileURL参数也存在，会只取File的内容。
         :type File: binary
-        :param FileURL: 文件的URL地址。FileBase64与FileURL有一个不为空即可，若FileBase64同时存在，那么取FileBase64。
+        :param FileURL: 文件的URL地址。File与FileURL不能同时为空，若File参数也存在，会只取File的内容。
         :type FileURL: str
         """
         self.File = None
