@@ -119,6 +119,9 @@ INTERNALERROR_GETRIGHTFAILED = 'InternalError.GetRightFailed'
 # 拉圈安全组详情失败。
 INTERNALERROR_GETSECURITYGROUPDETAILFAILED = 'InternalError.GetSecurityGroupDetailFailed'
 
+# 查询慢日志DB失败。
+INTERNALERROR_GETSLOWLOGFAILED = 'InternalError.GetSlowLogFailed'
+
 # 查询虚拟私有网络子网信息失败。
 INTERNALERROR_GETSUBNETFAILED = 'InternalError.GetSubnetFailed'
 
@@ -203,6 +206,9 @@ INVALIDPARAMETER_GENERICPARAMETERERROR = 'InvalidParameter.GenericParameterError
 # 非法参数。
 INVALIDPARAMETER_ILLEGALPARAMETERERROR = 'InvalidParameter.IllegalParameterError'
 
+# 错误的时间参数。
+INVALIDPARAMETER_ILLEGALTIME = 'InvalidParameter.IllegalTime'
+
 # 未找到请求的实例。
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
@@ -227,6 +233,9 @@ INVALIDPARAMETER_SUBNETUNAVAILABLE = 'InvalidParameter.SubnetUnavailable'
 # 找不到指定的虚拟私有网络。
 INVALIDPARAMETER_VPCNOTFOUND = 'InvalidParameter.VpcNotFound'
 
+# 可用区信息错误。
+INVALIDPARAMETER_ZONEIDILLEGAL = 'InvalidParameter.ZoneIdIllegal'
+
 # 想要创建的账号已经存在。
 INVALIDPARAMETERVALUE_ACCOUNTALREADYEXISTS = 'InvalidParameterValue.AccountAlreadyExists'
 
