@@ -54,6 +54,34 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def BindingPolicyTag(self, request):
+        """策略绑定标签
+
+        :param request: Request instance for BindingPolicyTag.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.BindingPolicyTagRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.BindingPolicyTagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("BindingPolicyTag", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.BindingPolicyTagResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAlarmNotice(self, request):
         """创建通知模板
 
@@ -875,7 +903,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeProductList(self, request):
-        """查询云监控产品列表
+        """查询云监控产品列表，支持云服务器CVM、云数据库、云消息队列、负载均衡、容器服务、专线等云产品。
 
         :param request: Request instance for DescribeProductList.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeProductListRequest`
